@@ -2,7 +2,7 @@
 """
 Created on Sun Apr 25 10:58:08 2021
 
-@author: ormondt
+@author: Maarten van Ormondt
 """
 
 import os
@@ -12,7 +12,7 @@ import math
 import urllib
 import netCDF4 as nc
 
-from cht.coordinate_systems import CS
+from .coordinate_systems import CS
 
 class ZoomLevel:
 
@@ -24,14 +24,24 @@ class ZoomLevel:
         self.j_available = []
 
 class BathymetryDatabase:
+
+    """
+    The main Bathymetry Database class
+    
+    :param pth: Path name where bathymetry tiles will be cached.
+    :type pth: string            
+    """
     
     def __init__(self, pth):
         
         self.path    = pth
         self.dataset = []
         self.read()
-        
+       
     def read(self):
+        """
+        Reads meta-data of all datasets in the database. 
+        """
         
         # Read in database
         xml_file = os.path.join(self.path, "bathymetry.xml")
@@ -59,6 +69,24 @@ class BathymetryDatabase:
                 pass
         
     def get_data(self, dataset_name, xlim, ylim, max_cell_size):
+        """
+        Returns imported data from database 
+        
+        :param dataset_name: Name of requested bathymetry dataset.
+        :type dataset_name: str
+        :param xlim: x-limits.
+        :type xlim: list
+        :param y_lim: y-limits.
+        :type y_lim: list
+        :param max_cell_size: Maximum cell size (in metres)
+        :type max_cell_size: float, optional
+        :param dx: dx
+        :type dx: float, optional
+        :param dx: dy
+        :type dy: float, optional
+        :param crs: name of coordinate reference system
+        :type crs: str, optional
+        """
         
         # Read in data from database
         # Find corresponding dataset dataset
@@ -68,12 +96,19 @@ class BathymetryDatabase:
                 return x, y, z
 
     def get_crs(self, dataset_name):
+        """
+        Returns coordinate reference system (CRS) of dataset
+
+        :param dataset_name: Name of requested bathymetry dataset.
+        :type dataset_name: str
+        :return: CRS  
+        :rtype: str
+        """
         
         # Read in data from database
         # Find corresponding dataset dataset
         for d in self.dataset:
             if d.name == dataset_name:
-#                crs = d.crs
                 return d.crs.epsg
 
     # def get_data_on_array(self, dataset_name, xarr, yarr, crs):
@@ -107,8 +142,14 @@ class BathymetryDatabase:
                 source_names.append(source)
         
         return sources
-        
+
 class BathymetryDataset:
+    """
+    Bathymetry dataset class 
+
+    :ivar name: initial value: ''
+    :ivar nr_zoom_levels: initial value: 0
+    """
 
     def __init__(self):
         
@@ -167,6 +208,9 @@ class BathymetryDataset:
             nny = math.ceil(nny/2)
             
     def get_data(self, xlim, ylim, max_cell_size):
+        """
+        Reads data from database. Returns x, y, z 
+        """
         
         x=0.0
         y=0.0
@@ -180,6 +224,9 @@ class BathymetryDataset:
         return x,y,z
         
     def read_data_from_netcdf_tiles(self, xl, yl, izoom, max_cell_size):
+        """
+        Reads data from database. Returns x, y, z 
+        """
         
         just_get_tiles = False
         iopendap       = False
