@@ -32,7 +32,11 @@ def copy_file(src, dst):
 def delete_file(src):
     
     for file_name in glob.glob(src):
-        os.remove(file_name)
+        os.remove(src)
+
+def rm(src):
+    
+    os.remove(src)
 
 def mkdir(path):
 
