@@ -21,6 +21,7 @@ from pyproj import Transformer
 from cht.geometry import RegularGrid
 from cht.geometry import Point
 from cht.deltares_ini import IniStruct
+from cht import tiling
 
 class SFINCS:
     
@@ -519,7 +520,6 @@ class SFINCS:
 
         else:
         
-            ddd=xr.open_dataset(zsmax_file)
             ind_file = os.path.join(self.path, self.input.indexfile)
     
             freqstr = str(self.input.dtmaxout) + "S"
@@ -665,9 +665,9 @@ class SFINCS:
         
     def make_index_tiles(self, path, zoom_range=None):
         
-        from tiling import deg2num
-        from tiling import num2deg
-        import fileops as fo
+        from cht.tiling import deg2num
+        from cht.tiling import num2deg
+        import cht.fileops as fo
         
         if not zoom_range:
             zoom_range = [0, 13]
